yt.visualization.fixed_resolution.FixedResolutionBuffer.export_hdf5 — The yt Project 3.2-dev documentation

# yt.visualization.fixed_resolution.FixedResolutionBuffer.export_hdf5

`FixedResolutionBuffer.` `export_hdf5`(filename, fields=None)

  Export a set of fields to a set of HDF5 datasets.

  This function will export any number of fields into datasets in a new HDF5 file.

  Parameters: | filename : string This file will be opened in “append” mode. fields : list of strings These fields will be pixelized and output.